"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const path_1 = tslib_1.__importDefault(require("path"));
const camelcase_1 = tslib_1.__importDefault(require("camelcase"));
// Remove the package name scope if it exists
exports.removeScope = (name) => name.replace(/^@.*\//, '');
// UMD-safe package name
exports.safeVariableName = (name) => camelcase_1.default(exports.removeScope(name)
    .toLowerCase()
    .replace(/((^[^a-zA-Z]+)|[^\w.-])|([^a-zA-Z0-9]+$)/g, ''));
exports.safePackageName = (name) => name
    .toLowerCase()
    .replace(/(^@.*\/)|((^[^a-zA-Z]+)|[^\w.-])|([^a-zA-Z0-9]+$)/g, '');
exports.external = (id) => !id.startsWith('.') && !path_1.default.isAbsolute(id);
// Make sure any symlinks in the project folder are resolved:
// https://github.com/facebookincubator/create-react-app/issues/637
exports.appDirectory = fs_extra_1.default.realpathSync(process.cwd());
exports.resolveApp = function (relativePath) {
    return path_1.default.resolve(exports.appDirectory, relativePath);
};
function findByPattern(startPath, filter) {
    console.log(startPath);
    if (fs_extra_1.default.existsSync(startPath)) {
        const files = fs_extra_1.default.readdirSync(startPath);
        for (let i = 0; i < files.length; i++) {
            const filename = path_1.default.join(startPath, files[i]);
            const stat = fs_extra_1.default.lstatSync(filename);
            const isNodeModule = filename.includes('node_modules');
            if (!isNodeModule && stat.isDirectory()) {
                findByPattern(filename, filter);
            }
            else if (!isNodeModule && filename.indexOf(filter) >= 0) {
                return filename;
            }
        }
    }
    return;
}
exports.findByPattern = findByPattern;
